# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self


class OneOf:
    @staticmethod
    def from_dict(obj, *args, **kwargs):
        """Noop override to fix missing OneOf import/implementation."""
        return obj


class Copy(BaseModel):
    """
    A serializer for Content Copy API.
    """ # noqa: E501
    config: Optional[Any] = Field(description="Content to be copied into the given destinations from the given sources.  Its a list of dictionaries with the following available fields:  ```json [   {     \"source_repo_version\": <RepositoryVersion [pulp_href|prn]>,     \"dest_repo\": <RpmRepository [pulp_href|prn]>,     \"dest_base_version\": <int>,     \"content\": [<Content [pulp_href|prn]>, ...]   },   ... ] ```  If domains are enabled, the refered pulp objects must be part of the current domain.  For usage examples, refer to the advanced copy guide: <https://pulpproject.org/pulp_rpm/docs/user/guides/modify/#advanced-copy-workflow> ")
    dependency_solving: Optional[StrictBool] = Field(default=True, description="Also copy dependencies of the content being copied.")
    __properties: ClassVar[List[str]] = ["config", "dependency_solving"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Copy from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if config (nullable) is None
        # and model_fields_set contains the field
        if self.config is None and "config" in self.model_fields_set:
            _dict['config'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Copy from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "config": obj.get("config"),
            "dependency_solving": obj.get("dependency_solving") if obj.get("dependency_solving") is not None else True
        })
        return _obj


